@@ -1,4 +1,4 @@
-/* Copyright 2012 Naikel Aparicio. All rights reserved.
+/* Copyright 2013 Naikel Aparicio. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -22,8 +22,8 @@
  * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * The views and conclusions contained in the software and documentation
- * are those of the authors and should not be interpreted as representing
- * official policies, either expressed or implied, of Eeli Reilin.
+ * are those of the author and should not be interpreted as representing
+ * official policies, either expressed or implied, of the copyright holder.
  */
 
 #ifndef FMESSAGE_H
@@ -47,7 +47,8 @@ public:
         ReceivedByServer,
         ReceivedByTarget,
         NeverSent,
-        ServerBounce
+        ServerBounce,
+        Played
     };
 
     enum ContentType {
@@ -67,7 +68,8 @@ public:
         Contact,
         Location,
         Divider,
-        System
+        System,
+        Voice
     };
 
     FMessage();
@@ -96,8 +98,9 @@ public:
 
     double latitude;
     double longitude;
-    QString location_details;
-    QString location_url;
+
+    bool live;
+
     qint32 media_duration_seconds;
     QString media_mime_type;
     QString media_name;
